# pyCallisto

pyCallisto is a image processing and data analysis python library developed for e-CALLISTO data (http://www.e-callisto.org/). However, this library could be used to process the data obtained using various solar radio spectrometers available around the globe.

# Installation

Now you can pip install it. Head over to Pypi to check the details.
https://pypi.org/project/pyCallisto/

# Pre-requisites and Standard Python Libraries 

    python 3.6,
    numpy<=1.26,
    matplotlib,
    astropy.

# Contributors

    Mr. Ravindra Pawase, 
    Data Scientist, 
    Cummins.inc, 
    Pune-411 004, India.
    
    Dr. K. Sasikumar Raja, 
    Assistant Professor, 
    Indian Institute Astrophysics, 
    II Block,Koramangla,Bengaluru-560 034,India.

# Feedback

If you have any feedback, queries, feature request you can drop a line at

    ravi.pawase@gmail.com
    sasikumarraja@gmail.com

# Citation

If you find pyCallisto useful and make use of it in your work, we appreciate acknowledging the same. We recommend using the following line: "This work is made use of the pyCallisto library, which is available at https://github.com/ravipawase/pyCallisto"


